@@ -2,7 +2,7 @@
                                    main.h
                              -------------------
     begin                : Wed Jul 25 2001
-    copyright            : (C) 2001 - 2003 by Roland Riegel
+    copyright            : (C) 2001 - 2008 by Roland Riegel
     email                : feedback@roland-riegel.de
  ***************************************************************************/
 
@@ -21,16 +21,14 @@
 #include "traffic_window.h"
 #include "opt_window.h"
 
-int main( int argc, char *argv[] );
+int main(int argc, char *argv[]);
 
 void init();
 void finish();
-void end( int signal = 0 );
-void terminal_resized( int signal );
+void end(int signal = 0);
+void terminalResized(int signal);
 
-void printhelp();
-
-OptWindow m_optwindow;
-TrafficWindow m_mainwindow;
+void printHelp(bool error);
 
 #endif
+
