@@ -2,7 +2,7 @@
                                  screen.cpp
                              -------------------
     begin                : Thu Nov 25 2003
-    copyright            : (C) 2003 by Roland Riegel
+    copyright            : (C) 2003 - 2008 by Roland Riegel
     email                : feedback@roland-riegel.de
  ***************************************************************************/
 
@@ -16,36 +16,41 @@
  ***************************************************************************/
 
 #include "screen.h"
+
 #include <curses.h>
+#undef clear
+#undef erase
+#undef refresh
 
 int Screen::width()
 {
-	int width;
-	int height;
-	getmaxyx( stdscr, height, width );
-	return width;
+    int width;
+    int height;
+    getmaxyx(stdscr, height, width);
+    return width;
 }
 
 int Screen::height()
 {
-	int width;
-	int height;
-	getmaxyx( stdscr, height, width );
-	return height;
+    int width;
+    int height;
+    getmaxyx(stdscr, height, width);
+    return height;
 }
 
 int Screen::x()
 {
-	int x;
-	int y;
-	getyx( stdscr, y, x );
-	return x;
+    int x;
+    int y;
+    getyx(stdscr, y, x);
+    return x;
 }
 
 int Screen::y()
 {
-	int x;
-	int y;
-	getyx( stdscr, y, x );
-	return y;
+    int x;
+    int y;
+    getyx(stdscr, y, x);
+    return y;
 }
+
